/*
 * Copyright (C) 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.view.translation;

import android.annotation.NonNull;
import android.os.Parcel;
import android.os.Parcelable;

import com.android.internal.util.DataClass;

/**
 * Specs and additional info for the translation data.
 *
 * <p>This spec help specify information such as the language/locale for the translation, as well
 * as the data format for the translation (text, audio, etc.)</p>
 */
@DataClass(genEqualsHashCode = true, genHiddenConstDefs = true)
public final class TranslationSpec implements Parcelable {

    /** Data format for translation is text. */
    public static final int DATA_FORMAT_TEXT = 1;

    /** @hide */
    @android.annotation.IntDef(prefix = "DATA_FORMAT_", value = {
            DATA_FORMAT_TEXT
    })
    @java.lang.annotation.Retention(java.lang.annotation.RetentionPolicy.SOURCE)
    @DataClass.Generated.Member
    public @interface DataFormat {}

    /**
     * String representation of language codes e.g. "en", "es", etc.
     */
    private final @NonNull String mLanguage;

    private final @DataFormat int mDataFormat;



    // Code below generated by codegen v1.0.22.
    //
    // DO NOT MODIFY!
    // CHECKSTYLE:OFF Generated code
    //
    // To regenerate run:
    // $ codegen $ANDROID_BUILD_TOP/frameworks/base/core/java/android/view/translation/TranslationSpec.java
    //
    // To exclude the generated code from IntelliJ auto-formatting enable (one-time):
    //   Settings > Editor > Code Style > Formatter Control
    //@formatter:off


    /**
     * Creates a new TranslationSpec.
     *
     * @param language
     *   String representation of language codes e.g. "en", "es", etc.
     */
    @DataClass.Generated.Member
    public TranslationSpec(
            @NonNull String language,
            @DataFormat int dataFormat) {
        this.mLanguage = language;
        com.android.internal.util.AnnotationValidations.validate(
                NonNull.class, null, mLanguage);
        this.mDataFormat = dataFormat;
        com.android.internal.util.AnnotationValidations.validate(
                DataFormat.class, null, mDataFormat);

        // onConstructed(); // You can define this method to get a callback
    }

    /**
     * String representation of language codes e.g. "en", "es", etc.
     */
    @DataClass.Generated.Member
    public @NonNull String getLanguage() {
        return mLanguage;
    }

    @DataClass.Generated.Member
    public @DataFormat int getDataFormat() {
        return mDataFormat;
    }

    @Override
    @DataClass.Generated.Member
    public boolean equals(@android.annotation.Nullable Object o) {
        // You can override field equality logic by defining either of the methods like:
        // boolean fieldNameEquals(TranslationSpec other) { ... }
        // boolean fieldNameEquals(FieldType otherValue) { ... }

        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        @SuppressWarnings("unchecked")
        TranslationSpec that = (TranslationSpec) o;
        //noinspection PointlessBooleanExpression
        return true
                && java.util.Objects.equals(mLanguage, that.mLanguage)
                && mDataFormat == that.mDataFormat;
    }

    @Override
    @DataClass.Generated.Member
    public int hashCode() {
        // You can override field hashCode logic by defining methods like:
        // int fieldNameHashCode() { ... }

        int _hash = 1;
        _hash = 31 * _hash + java.util.Objects.hashCode(mLanguage);
        _hash = 31 * _hash + mDataFormat;
        return _hash;
    }

    @Override
    @DataClass.Generated.Member
    public void writeToParcel(@NonNull Parcel dest, int flags) {
        // You can override field parcelling by defining methods like:
        // void parcelFieldName(Parcel dest, int flags) { ... }

        dest.writeString(mLanguage);
        dest.writeInt(mDataFormat);
    }

    @Override
    @DataClass.Generated.Member
    public int describeContents() { return 0; }

    /** @hide */
    @SuppressWarnings({"unchecked", "RedundantCast"})
    @DataClass.Generated.Member
    /* package-private */ TranslationSpec(@NonNull Parcel in) {
        // You can override field unparcelling by defining methods like:
        // static FieldType unparcelFieldName(Parcel in) { ... }

        String language = in.readString();
        int dataFormat = in.readInt();

        this.mLanguage = language;
        com.android.internal.util.AnnotationValidations.validate(
                NonNull.class, null, mLanguage);
        this.mDataFormat = dataFormat;
        com.android.internal.util.AnnotationValidations.validate(
                DataFormat.class, null, mDataFormat);

        // onConstructed(); // You can define this method to get a callback
    }

    @DataClass.Generated.Member
    public static final @NonNull Parcelable.Creator<TranslationSpec> CREATOR
            = new Parcelable.Creator<TranslationSpec>() {
        @Override
        public TranslationSpec[] newArray(int size) {
            return new TranslationSpec[size];
        }

        @Override
        public TranslationSpec createFromParcel(@NonNull Parcel in) {
            return new TranslationSpec(in);
        }
    };

    @DataClass.Generated(
            time = 1609964630624L,
            codegenVersion = "1.0.22",
            sourceFile = "frameworks/base/core/java/android/view/translation/TranslationSpec.java",
            inputSignatures = "public static final  int DATA_FORMAT_TEXT\nprivate final @android.annotation.NonNull java.lang.String mLanguage\nprivate final @android.view.translation.TranslationSpec.DataFormat int mDataFormat\nclass TranslationSpec extends java.lang.Object implements [android.os.Parcelable]\n@com.android.internal.util.DataClass(genEqualsHashCode=true, genHiddenConstDefs=true)")
    @Deprecated
    private void __metadata() {}


    //@formatter:on
    // End of generated code

}
